@@ -117,6 +117,13 @@ class CustomConfiguration(object):
         self.__page_keys       = self.__ui.get_widget('page_keys')
         self.__treeview_keys   = self.__ui.get_widget('treeview_keys')
         self.__hbuttonbox_keys = self.__ui.get_widget('hbuttonbox_keys')
+        self.__label_keys_hint = self.__ui.get_widget('label_keys_hint')
+        self.__image_keys_hint = self.__ui.get_widget('image_keys_hint')
+
+        self.__keys_learning_hint = _(
+            '<b>Learning new key code.</b>\n'
+            'Press the button on your remote control which should emit this key-code.')
+        self.__keys_default_hint = self.__label_keys_hint.get_label()
 
         # pylint: disable-msg=W0613
         def editing_started(cell, editable, path):
@@ -147,6 +154,8 @@ class CustomConfiguration(object):
                 keys_model.update_key(new_name, mapping.code)
                 self.select_key(new_name)
 
+            self.__treeview_keys.grab_focus()
+
         keys_renderer = gtk.CellRendererCombo()
         keys_renderer.set_properties(editable=True, text_column=0,
                                      model=self.default_keys)
@@ -295,6 +304,11 @@ class CustomConfiguration(object):
         try:
             bus     = backend.get_service_bus()
             service = backend.get_service(bus)
+
+            # Stop the lirc deamon, as some drivers (e.g. lirc_streamzap) do
+            # not support concurrent device access:
+            service.ManageLircDaemon('stop')
+
             driver  = service.LearnKeyCode(driver, device, configuration, [mapping.key])
 
             driver = bus.get_object(service.requested_bus_name, driver)
@@ -308,7 +322,7 @@ class CustomConfiguration(object):
             driver.Execute()
 
         except dbus.DBusException, ex:
-            report_failure.__direct__(ex.message)
+            report_failure.callback(ex.message)
 
         self._on_dialog_changed()
 
@@ -322,6 +336,13 @@ class CustomConfiguration(object):
             except dbus.DBusException, ex:
                 logging.error(ex)
 
+            try:
+                # restart the lirc deamon (we stopped it before learning):
+                backend.get_service().ManageLircDaemon('start')
+
+            except dbus.DBusException, ex:
+                logging.error(ex)
+
             self.__learning_driver = None
 
         if self.__learning_row:
@@ -348,7 +369,7 @@ class CustomConfiguration(object):
         def configuration_problem(message):
             '''
             Informs the user about configuration file problems,
-            and ask the user for accption or rejection.
+            and ask the user for acceptance or rejection.
             '''
 
             response_buttons = (
@@ -363,8 +384,10 @@ class CustomConfiguration(object):
                     message, buttons=response_buttons))
 
         def on_upload_finished(message):
-            '''Informs the user about succeeding uploads.'''
+            '''Informs the user about successful uploads.'''
 
+            # The message is usually some "thanks" text from the server side:
+            # TODO: Is this wise? It will not be translated?
             show_message(self.__dialog, _('Upload Succeeded'),
                          message, message_type=gtk.MESSAGE_INFO)
             self.__dialog.set_sensitive(True)
@@ -392,7 +415,7 @@ class CustomConfiguration(object):
         self.__dialog.set_sensitive(False)
 
         net.post_file(target_uri=config.URI_UPLOADS,
-                      filename=lirc.find_remote_config(),
+                      filename=lirc.find_remote_config()[0],
                       content=self.__remote.configuration,
                       context=_('customized configuration file'),
                       finished_callback=on_upload_finished,
@@ -493,7 +516,7 @@ class CustomConfiguration(object):
             self.__progressbar_detect_basics.show()
 
         except dbus.DBusException, ex:
-            report_failure.__direct__(ex.message)
+            report_failure.callback(ex.message)
             self.__stop_detection()
 
     def __stop_detection(self):
@@ -522,7 +545,7 @@ class CustomConfiguration(object):
         keys_complete = (basics_complete and have_keys)
 
         selection = self.__treeview_keys.get_selection()
-        keys_model, keys_iter = selection.get_selected()
+        keys_iter = selection.get_selected()[1]
 
         # Update state of global widgets:
         self.__button_ok.set_sensitive(model_complete)
@@ -545,6 +568,12 @@ class CustomConfiguration(object):
         self.__button_keys_learn.set_sensitive(keys_iter is not None)
         self.__button_keys_learn.set_active(is_learning)
 
+        self.__label_keys_hint.set_markup(is_learning and
+                                          self.__keys_learning_hint or
+                                          self.__keys_default_hint)
+
+        self.__image_keys_hint.set_property('visible', is_learning)
+
     def select_key(self, key_name):
         '''Select the row of the specified key.'''
 
@@ -665,6 +694,13 @@ class CustomConfiguration(object):
         if gtk.RESPONSE_OK == response:
             try:
                 service = backend.get_service()
+
+                # Get the entered basic information, 
+                # so it will be written to the configuration file: 
+                self.__remote.contributor = self.contributor_name
+                self.__remote.vendor = self.vendor_name
+                self.__remote.product = self.product_name
+
                 self.__remote.update_configuration(service)
                 service.ManageLircDaemon('restart')
 
