@@ -240,7 +240,8 @@ class RemoteControlProperties(object):
             remote.vendor, remote.product), buttons=responses))
 
     def __restore_hardware_settings(self):
-        '''Restore hardware settings from configuration files.'''
+        '''Restore hardware settings from configuration files.
+	'''
 
         # We really do not want to rewrite any configuration files
         # at that stage, so __configuration_level should be non-zero.
@@ -250,11 +251,27 @@ class RemoteControlProperties(object):
         settings = lirc.HardwareConfParser(config.LIRC_HARDWARE_CONF)
 
         # Practice some sanity checks on that file:
-        remote = self.__remotes_db.find(settings.get('REMOTE_VENDOR'),
-                                        settings.get('REMOTE_MODEL'))
+        remote_vendor = settings.get('REMOTE_VENDOR')
+        remote_model = settings.get('REMOTE_MODEL')
+        remote = self.__remotes_db.find(remote_vendor, remote_model)
+
+        if(remote is None):
+            print("__restore_hardware_settings(): No remote found in the db for remote_vendor=%s, remote_model=%s\n" % (remote_vendor, remote_model))
 
         if (not lirc.check_hardware_settings(remote) and
             self.__confirm_rewrite_configuration(remote)):
+
+            # We must create a dialog (the main dialog has not yet been realized) 
+            # because PolicyKit needs a window ID:
+            progress_dialog = gtk.MessageDialog(parent=self.__dialog, flags=gtk.DIALOG_MODAL, type=gtk.MESSAGE_INFO, message_format = _("Restoring Configuration"))
+            progress_dialog.show()
+
+            granted = self._unlock(progress_dialog) # This requires sudo access, so ask for it if necessary.
+            progress_dialog.destroy()
+
+            if not granted:
+                return
+
             try:
                 service = backend.get_service()
 
@@ -301,7 +318,8 @@ class RemoteControlProperties(object):
         else:
             self.__label_preview_result.hide()
             self.__label_preview_status.set_markup(_('<b>Warning:</b> Remote control daemon ' +
-                                                     'not running. Cannot test buttons.'))
+                                                     'not running. Cannot test buttons.\n' + 
+                                                     'This could be due to a configuration error. Try changing the configuration.'))
 
     # pylint: disable-msg=W0613,R0913
     def __on_lirc_key_pressed(self, listener, remote, repeat, name, code):
@@ -425,7 +443,7 @@ class RemoteControlProperties(object):
         xpad = widget.get_child().allocation.x - widget.allocation.x
         self.__alignment_remote_selection.set_padding(0, 0, xpad, 0)
 
-    def _on_vendor_list_changed(self, vendor_list):
+    def _on_receiver_vendor_list_changed(self, vendor_list):
         '''
         Change the combobox to show the list of models for the selected 
         manufacturer:
@@ -511,8 +529,8 @@ class RemoteControlProperties(object):
 
         self._on_spinbutton_device_value_changed()
 
-    def _on_combo_device_changed(self, combo=None):
-        '''Handle changes to device combo-box.'''
+    def _on_receiver_combo_device_changed(self, combo=None):
+        '''Handle changes to receiver device combo-box.'''
 
         receiver = self.selected_receiver
         device = self.selected_device
@@ -535,7 +553,7 @@ class RemoteControlProperties(object):
 
         self.selected_device = ('%d' % self.__spinbutton_device.get_value())
 
-    def _on_product_list_changed(self, product_list):
+    def _on_receiver_product_list_changed(self, product_list):
         '''Handle selection changes to receiver product list.'''
 
         # lookup selection:
@@ -790,7 +808,7 @@ class RemoteControlProperties(object):
         if granted:
             self.__combo_receiver_vendor_list.grab_focus()
 
-    def _unlock(self):
+    def _unlock(self, parent_dialog):
         '''
         Ask PolicyKit to allow the user to use our D-BUS driven backend.
         We must ask PolicyKit again later before actually using the backend,
@@ -801,12 +819,15 @@ class RemoteControlProperties(object):
         See http://bugs.freedesktop.org/show_bug.cgi?id=14600
         '''
 
-        if self.__dialog == None:
+        if(parent_dialog is None):
+            parent_dialog = self.__dialog
+
+        if parent_dialog == None:
             logging.warning('_unlock() called before the dialog ' +
                             'was instantiated, but we need an xid')
             return False
 
-        if not self.__dialog.window:
+        if not parent_dialog.window:
             logging.warning('_unlock() called before the dialog ' +
                             'was realized, but we need an xid')
             return False
@@ -815,7 +836,7 @@ class RemoteControlProperties(object):
             logging.info('Authorized already. No need to obtain authorization.')
             return True
 
-        granted = self.__auth.obtain_authorization(self.__dialog)
+        granted = self.__auth.obtain_authorization(parent_dialog)
 
         # Warn the user (because PolicyKit does not seem to)
         # Note that PolicyKit can fail silently (just returning 0) when
@@ -826,11 +847,9 @@ class RemoteControlProperties(object):
             # (PolicyKit should maybe show this instead of failing silently,
             # or at least something should be recommended by PolicyKit.):
             # See http://bugs.freedesktop.org/show_bug.cgi?id=14599
-            show_message(self.__dialog,
+            show_message(parent_dialog,
                          _('Could Not Unlock.'),
-                         _('The system will not allow you to access ' +
-                           'these features. Please contact your system ' +
-                           'administrator for assistance.'))
+                         _('The system will not allow you to access these features. Please contact your system administrator for assistance.'))
 
         self._set_widgets_locked(not granted)
 
